@@ -12,7 +12,7 @@ use Params::Validate ':all';
 our ($VERSION, @EXPORT_OK, %EXPORT_TAGS);
 my @subs;
 
-$VERSION = '0.7_02';
+$VERSION = '0.8_01';
 @subs = qw(exact_wrap fuzzy_wrap);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ('all' => [ @subs ]);
@@ -29,6 +29,17 @@ validation_options(
     stack_skip => 2,
 );
 
+my $pre_process = sub
+{
+    local $_ = ${$_[0]};
+
+    s/^\s+//;
+    s/\s+$//;
+    s/\s+/ /g;
+
+    ${$_[0]} = $_;
+};
+
 my $calc_average = sub
 {
     my ($text, $wrap_at) = @_;
@@ -49,6 +60,9 @@ sub exact_wrap
     _validate(@_);
     my ($text, $wrap_at) = @_;
 
+    $pre_process->(\$text);
+    return () unless length $text;
+
     $wrap_at ||= WRAP_AT_DEFAULT;
     my $average = $calc_average->($text, $wrap_at);
 
@@ -60,6 +74,9 @@ sub fuzzy_wrap
     _validate(@_);
     my ($text, $wrap_at) = @_;
 
+    $pre_process->(\$text);
+    return () unless length $text;
+
     $wrap_at ||= WRAP_AT_DEFAULT;
     my $average = $calc_average->($text, $wrap_at);
 
@@ -83,14 +100,6 @@ sub _fuzzy_wrap
 {
     my ($text, $average) = @_;
 
-    $text = do {
-        local $_ = $text;
-        s/^\s+//;
-        s/\s+$//;
-        s/\s+/ /g;
-        $_
-    };
-
       my @spaces;
     push @spaces, pos $text while $text =~ /(?= )/g;
 
